{% set clients = server.clients %}
{% for headline, clients in [
    ('Onlinetime', clients.onlinetime),
    ('Kicks', clients.kicks),
    ('Passive kicks', clients.pkicks),
    ('Bans', clients.bans),
    ('Passive bans', clients.pbans)
] %}
  {% if clients|length > 0 %}
  {% set headline_id = [server.sid, headline|lower|replace(' ', '_')]|join('.') %}
  <h2><a href="#{{ headline_id }}">{{ headline }}</a></h2>
  <ul class="list-group my-3" id="{{ headline_id }}">
    {% for client, value in clients %}
    {% set id = [headline_id, client.nick|striptags]|join('.') %}
    <li id="{{ id }}" class="list-group-item d-flex justify-content-between align-items-center{{ ' list-group-item-success' if client.connected else loop.cycle('" style="background-color: #eee;', '') }}">
      <span class="hint--right hint--medium--xs hint--no-shadow" data-hint="{{ client.nick_history|join(', ') }}"><a href="#{{ id }}">{{ client.nick }}{{ " (" + client.identifier + ")" if debug }}</a></span>
      <span class="badge badge-secondary badge-pill"><div{% if not client.connected and headline == 'Onlinetime' %} class="hint--left hint--no-shadow" data-hint="{{ client.last_seen|lastseen }}"{% endif %}>{{ value }}</div></span>
    </li>
    {% endfor %}
  </ul>
  {% endif %}
{% endfor %}
